# Generated by roxygen2: do not edit by hand

S3method(coef,eiv_mlr)
S3method(confint,eiv_mlr)
S3method(predict,eiv_mlr)
S3method(print,eiv_mlr)
S3method(residuals,eiv_mlr)
S3method(summary,eiv_mlr)
S3method(vcov,eiv_mlr)
export(eiv_mlr)
importFrom(stats,.getXlevels)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,cov)
importFrom(stats,model.matrix)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,rbinom)
importFrom(stats,reformulate)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,symnum)
importFrom(stats,terms)
importFrom(stats,uniroot)
