% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Wrapper_output_functions.R
\name{residuals.eiv_mlr}
\alias{residuals.eiv_mlr}
\title{Residuals from an Errors-in-Variables Linear Model}
\usage{
\method{residuals}{eiv_mlr}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"eiv_mlr"}.}

\item{...}{Not used.}
}
\value{
A numeric vector of residuals.
}
\description{
Computes plug-in residuals based on observed covariates and estimated
coefficients. Measurement error is not corrected in residuals.
}
