% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Wrapper_output_functions.R
\name{summary.eiv_mlr}
\alias{summary.eiv_mlr}
\title{Summary of an Errors-in-Variables Linear Model}
\usage{
\method{summary}{eiv_mlr}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"eiv_mlr"}.}

\item{...}{Not used.}
}
\value{
An object of class \code{"summary"} containing a
  coefficient table and model information.
}
\description{
Produces a coefficient table including standard errors, z-statistics,
p-values, and significance stars.
}
