% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Wrapper_output_functions.R
\name{vcov.eiv_mlr}
\alias{vcov.eiv_mlr}
\title{Variance-Covariance Matrix for eiv_mlr Objects}
\usage{
\method{vcov}{eiv_mlr}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"eiv_mlr"}.}

\item{...}{Not used.}
}
\value{
A numeric variance-covariance matrix of the parameter estimates.
}
\description{
Variance-Covariance Matrix for eiv_mlr Objects
}
