% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Wrapper_output_functions.R
\name{print.eiv_mlr}
\alias{print.eiv_mlr}
\title{Print Method for eiv_mlr Objects}
\usage{
\method{print}{eiv_mlr}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"eiv_mlr"}.}

\item{...}{Not used.}
}
\value{
Invisibly returns the input object \code{x} of class \code{"eiv_mlr"}.
This function is called for its side effect of printing a summary of the model.
}
\description{
Displays a concise summary of an errors-in-variables linear model fit.
}
