% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dietary_white_women.R
\docType{data}
\name{dietary_white_women}
\alias{dietary_white_women}
\title{dietary_white_women}
\format{
A data frame with 2 rows per individual (one per recall day).
\describe{
  \item{unit}{Integer unit identifier}
  \item{bmi}{Body Mass Index (kg/m^2)}
  \item{energy}{Total energy intake (kcal)}
  \item{protein}{Protein intake (g)}
  \item{fat}{Fat intake (g)}
  \item{age_in_month}{Age in months}
  \item{replicate}{Replicate id of each observation}
}
}
\source{
Processed from NHANES dietary recall data.
}
\usage{
dietary_white_women
}
\description{
A processed Dataset containing repeated 24-hour dietary recalls.
}
\details{
The variables \code{energy}, \code{protein}, and \code{fat}
are treated as error-prone covariates with two replicate
measurements per individual, and age_in_month is treated as error-free
covariate.
}
\keyword{datasets}
