% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PhaseGradient.R
\name{PhaseGradient}
\alias{PhaseGradient}
\title{Gradient of the phase-function estimating equations}
\usage{
PhaseGradient(beta, S_y, C_y, WZ, t, estWeight)
}
\arguments{
\item{beta}{Numeric vector of length \code{p + q} containing the regression
coefficients.}

\item{S_y}{Numeric vector containing \code{sum_j sin(t * Y_j)} evaluated on
the grid \code{t}.}

\item{C_y}{Numeric vector containing \code{sum_j cos(t * Y_j)} evaluated on
the grid \code{t}.}

\item{WZ}{Numeric matrix of dimension \code{n x (p + q)} containing all
covariates.}

\item{t}{Numeric vector giving the grid of frequency values.}

\item{estWeight}{Numeric vector of length \code{n} giving observation
weights.}
}
\value{
Numeric vector of length \code{p + q} containing the phase-function
  gradient evaluated at \code{beta}.
}
\description{
Computes the gradient of the phase-function estimating equations with
respect to the regression coefficients.
}
\keyword{internal}
