% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/computing_corrected_estimator.R
\name{computing_corrected_estimator}
\alias{computing_corrected_estimator}
\title{Compute the corrected estimator via estimating equations}
\usage{
computing_corrected_estimator(y, Wbar, Zmat, estSigmaU_bar, beta_in = NULL)
}
\arguments{
\item{y}{Numeric vector of length \code{n}. Response variable.}

\item{Wbar}{Numeric matrix of dimension \code{n × p}. Error-prone
covariates at the averaged (replicate) level.}

\item{Zmat}{Numeric matrix of dimension \code{n × q}. Error-free
covariates (including intercept if applicable).}

\item{estSigmaU_bar}{Measurement error variance/covariance associated
with the averaged covariates. Can be \code{n × p × p} or \code{n × 1}.}

\item{beta_in}{Optional numeric vector of length \code{p + q}. Initial
value for the estimating equation solver.}
}
\value{
Numeric vector of length \code{p + q}, the corrected estimator.
}
\description{
This function computes the corrected estimator for a linear model
with measurement error in covariates by solving the corrected
estimating equations using a nonlinear root-finding algorithm.
}
\details{
The estimator is obtained by solving
\deqn{E_n(\beta) = 0}
where \code{E_n} is the corrected estimating equation implemented in
\code{estim_eq_corrected()}.
}
\seealso{
\code{\link{estim_eq_corrected}}
}
\keyword{internal}
