% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Wrapper_output_functions.R
\name{coef.eiv_mlr}
\alias{coef.eiv_mlr}
\title{Extract Coefficients from an eiv_mlr Object}
\usage{
\method{coef}{eiv_mlr}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"eiv_mlr"}.}

\item{...}{Not used.}
}
\value{
A named numeric vector of estimated regression coefficients.
}
\description{
Extract Coefficients from an eiv_mlr Object
}
